@@ -4,8 +4,9 @@ This plugin provides command-line options for controlling whether and how tests
 make use of online data.
 """
 import pytest
+from packaging.version import Version
+
 from .disable_internet import turn_off_internet, turn_on_internet
-from distutils.version import LooseVersion
 
 
 def pytest_addoption(parser):
@@ -34,9 +35,11 @@ def pytest_configure(config):
     strict_check = bool(config.getini('remote_data_strict'))
 
     remote_data = config.getoption('remote_data')
-    if remote_data not in ['astropy', 'any', 'github', 'none']:
+    options = ['astropy', 'any', 'github', 'none']
+    if remote_data not in options:
         raise pytest.UsageError(
-            "'{}' is not a valid source for remote data".format(remote_data))
+            "'{}' is not a valid source for remote data, "
+            "use one of '{}'".format(remote_data, "', '".join(options)))
 
     # Monkeypatch to deny access to remote resources unless explicitly told
     # otherwise
@@ -62,7 +65,7 @@ def pytest_unconfigure():
 
 def pytest_runtest_setup(item):
 
-    if LooseVersion(pytest.__version__) < LooseVersion("3.6"):
+    if Version(pytest.__version__) < Version("3.6"):
         remote_data = item.get_marker('remote_data')
         internet_off = item.get_marker('internet_off')
     else:
